# AgentiCraft Vision & Principles

## 🎯 Our North Star

**Build AI agents as simple as writing Python.**

No complex abstractions. No graph theory. No 500-page documentation. Just clean, simple code that works.

## 🧠 What Makes Us Different

### 1. **Reasoning Transparency**
Every agent shows you how it thinks:
```python
response = agent.run("Solve this problem")
print(response.reasoning)  # See the thought process!
```

This isn't just logging - it's a window into your agent's decision-making process.

### 2. **5-Minute Promise**
From installation to working agent in 5 minutes. We measure this. We optimize for this. If it takes longer, we've failed.

### 3. **Production-First**
- Built-in OpenTelemetry (not an afterthought)
- Real templates that deploy (not toy examples)
- Error messages that help (not confuse)
- Performance tracking from day one

### 4. **Two Types of Memory**
Others offer 5+ memory types. We offer 2:
- **ConversationMemory**: Recent context
- **KnowledgeMemory**: Long-term facts

Why? Because that's all you need in practice.

## 📊 How We Measure Success

| Metric | Target | Why It Matters |
|--------|--------|----------------|
| Time to First Agent | < 5 min | Developer experience |
| Core Size | < 2000 LOC | Maintainability |
| Documentation Coverage | 100% | No guessing |
| Example Success Rate | 100% | Trust |
| Error Message Clarity | "Helpful" | Debugging ease |

## 🚫 What We're NOT

- **NOT another LangChain**: We choose simplicity over features
- **NOT a research project**: We ship working code
- **NOT a black box**: Transparency is core to our design
- **NOT enterprise-only**: Free and open for everyone

## 💎 Core Principles

### 1. **Show Your Work**
Agents should explain their reasoning. Trust comes from transparency.

### 2. **Progressive Complexity**
Simple by default, powerful when needed. Start simple, grow as you need.

### 3. **Documentation = Code**
If it's not documented, it doesn't exist. Write docs first, code second.

### 4. **Real-World Focus**
Every feature must solve an actual problem. No academic exercises.

### 5. **Community First**
Built in public. Feedback incorporated. Contributors celebrated.

## 🎓 Learning from Others

We studied existing frameworks and learned:
- **From LangChain**: The cost of complexity
- **From AutoGen**: The value of agent communication  
- **From Agentic Framework**: The importance of MCP support
- **From the community**: What developers actually need

## 🚀 Where We're Going

### v0.1.0 ✅
- Core framework that works
- Reasoning transparency
- Production templates
- MCP support

### v0.2.0 (July 2025)
- Streaming responses
- Advanced reasoning patterns
- Tool marketplace
- Performance optimizations

### v1.0.0 (Q4 2025)
- Stable API guarantee
- Enterprise features
- Cloud deployment helpers
- 1000+ community tools

## 🤝 Join Us

This isn't just our framework - it's yours too. We build in public because:
- Your feedback makes us better
- Your use cases drive our roadmap
- Your contributions expand our capabilities
- Your success is our success

## 📝 Our Promise

1. **We will keep the core simple** (<2000 LOC forever)
2. **We will document everything** (100% coverage)
3. **We will show our reasoning** (transparency default)
4. **We will support production use** (from day one)
5. **We will listen to you** (community-driven)

---

*"The best framework is the one that gets out of your way."*

**Ready to build?** Start here: [Quickstart Guide](docs/quickstart.md)
